@@ -22,7 +22,7 @@ class AllMixin:
         args.message += '\n' + '\n'.join(lines) 
         args.message += '\nSelect:'
 ##        self.text(args)
-        args.default=str(args.default)
+        args.default=unicode(args.default)
         i = self.ask_string(args)
         return i
     
